==> themed_fast_404-1.0.5.tar.gz: themed_fast_404/src/Config/ConfigOverrider.php <==
<?php

namespace Drupal\themed_fast_404\Config;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Config\ConfigFactoryOverrideInterface;
use Drupal\Core\Config\StorageInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\File\FileUrlGeneratorInterface;
use Drupal\themed_fast_404\ThemedFast404ManagerInterface;

/**
 * Automatically overrides system.performance.fast_404 configuration.
 */
class ConfigOverrider implements ConfigFactoryOverrideInterface {

  /**
   * The file system service.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * The file URL generator.
   *
   * @var \Drupal\Core\File\FileUrlGeneratorInterface
   */
  protected $fileUrlGenerator;

  /**
   * Construct config override service.
   *
   * @param \Drupal\Core\File\FileSystemInterface $file_system
   *   The file handler.
   * @param \Drupal\Core\File\FileUrlGeneratorInterface $file_url_generator
   *   The file URL generator.
   */
  public function __construct(FileSystemInterface $file_system, FileUrlGeneratorInterface $file_url_generator) {
    $this->fileSystem = $file_system;
    $this->fileUrlGenerator = $file_url_generator;
  }

  /**
   * {@inheritdoc}
   */
  public function loadOverrides($names) {
    // Validation.
    if (!in_array('system.performance', $names)) {
      return [];
    }

    // Get current language id.
    // Can't use DI because of circular references on module install.
    $lng_id = \Drupal::service('language_manager')->getCurrentLanguage()->getId();

    // Get 404 file absolute url and real path.
    $uri = ThemedFast404ManagerInterface::PAGE_NOT_FOUND_FILE_PATH . 'page-not-found-' . $lng_id . '.html';
    $url = $this->fileUrlGenerator->generateAbsoluteString($uri);
    $real_path = $this->fileSystem->realpath($uri);

    // Set fast 404 config.
    // It the static file isn't generated yet, fallback to default settings.
    if (file_exists($real_path)) {
      $overrides['system.performance']['fast_404']['html'] = @file_get_contents($url);
    }
    $overrides['system.performance']['fast_404']['exclude_paths'] = '/\/(?:styles)|(?:system\/files)\//';
    $overrides['system.performance']['fast_404']['paths'] = '/\.*$/i';

    return $overrides;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheSuffix() {
    return 'ConfigOverrider';
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata($name) {
    return new CacheableMetadata();
  }

  /**
   * {@inheritdoc}
   */
  public function createConfigObject($name, $collection = StorageInterface::DEFAULT_COLLECTION) {
    return NULL;
  }

}

==> themed_fast_404-1.0.7.tar.gz: themed_fast_404/src/Config/ConfigOverrider.php <==
<?php

namespace Drupal\themed_fast_404\Config;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Config\ConfigFactoryOverrideInterface;
use Drupal\Core\Config\StorageInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\File\FileUrlGeneratorInterface;
use Drupal\themed_fast_404\ThemedFast404ManagerInterface;

/**
 * Automatically overrides system.performance.fast_404 configuration.
 */
class ConfigOverrider implements ConfigFactoryOverrideInterface {

  /**
   * Construct config override service.
   */
  public function __construct(
    protected FileSystemInterface $file_system,
    protected FileUrlGeneratorInterface $fileUrlGenerator,
    protected ThemedFast404ManagerInterface $themedFast404Manager,
  ) {}

  /**
   * {@inheritdoc}
   */
  public function loadOverrides($names) {
    // Validation.
    if (!in_array('system.performance', $names)) {
      return [];
    }

    // Get static 404 page url.
    $url = $this->themedFast404Manager->getStatic404url();
    if ($url) {
      $overrides['system.performance']['fast_404']['html'] = @file_get_contents($url);
    }

    $overrides['system.performance']['fast_404']['exclude_paths'] = '/\/(?:styles)|(?:system\/files)\//';
    $overrides['system.performance']['fast_404']['paths'] = '/\.*$/i';

    return $overrides;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheSuffix() {
    return 'ConfigOverrider';
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata($name) {
    return new CacheableMetadata();
  }

  /**
   * {@inheritdoc}
   */
  public function createConfigObject($name, $collection = StorageInterface::DEFAULT_COLLECTION) {
    return NULL;
  }

}
